@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.015-16-g0485a67
+package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.016-3-g5340f8b
 # ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use Moose;
 use MooseX::Types;
@@ -92,22 +92,21 @@ sub gather_files
     {
         if ($plugin->can('gather_files'))
         {
-            # if a Build.PL was created, remove it from the file list and save it for later
+            # if a Build.PL was created, save it and cache its content
             $plugin->gather_files;
             if (my $build_pl = first { $_->name eq 'Build.PL' } @{ $self->zilla->files })
             {
                 $self->log_debug('setting aside Build.PL created by ' . blessed($plugin));
                 $files{ blessed $plugin }{file} = $build_pl;
                 $files{ blessed $plugin }{content} = $build_pl->content;
-                $self->zilla->prune_file($build_pl);
+
+                # we leave the MBT version in place; we will fold our content
+                # into this object later
+                $self->zilla->prune_file($build_pl) if blessed($plugin) eq 'Dist::Zilla::Plugin::ModuleBuild';
             }
         }
     }
 
-    # put the Module::Build::Tiny file back in the file list in case other
-    # plugins want to add to its content
-    if (my $file = $files{'Dist::Zilla::Plugin::ModuleBuildTiny'}{file}) { push @{ $self->zilla->files }, $file }
-
     return;
 }
 
@@ -352,7 +351,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Modu
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
